% wymaga biblioteki CALFEM wersja 3.4
% 12-2013


warning off MATLAB:break_outside_of_loop
%----------------------------------------------------------------
% Rama 
% Obcienia  - sia skupiona
%             - obcienie cige
%
% Katedra Mechaniki Konstrukcji
%----------------------------------------------------------------

clear all
close all
clc

% ----- Wsprzdne wzw --------------------------------------

Coord = [0 0;
         0 8;
         6 0;
         6 8;
         9 0;
         9 10];
     
% ----- Stopnie swobody wzw ----------------------------------

Dof = [ 1  2  3;
        4  5  6;
        7  8  9;
       10 11 13;
       14 15 16;
       17 18 20];
      
%----- Macierz topologii Edof -----------------------------------

Edof =[ 1  1  2  3  4  5  6;
        2  7  8  9 10 11 12;
        3 14 15 16 17 18 19;
        4  4  5  6 10 11 12;
        5 10 11 13 17 18 20];

%----- Rozwinicie macierzy Coord w macierze ex oraz ey ---------
      
[ex,ey] = coordxtr(Edof, Coord, Dof, 2);
      
%----- Charakterystyki geometryczne i materiaowe ---------------

b=0.1; h=0.5;       % wymiary [m]
A1=b*h;             % pole przekroju [m2]
I1=b*h^3/12;        % moment bezwadnoci [m4]
E1=29e9;            % modu Young'a [Pa] dla betonu klasy B25

A2=116e-4;          % pole przekroju [m2] dla IPE500
I2=48200e-8;        % moment bezwadnoci [m4] dla IPE500
E2=210e9;           % modu Young'a [Pa] dla stali 

ep = [ E1 A1 I1;
       E1 A1 I1;
       E2 A2 I2;
       E1 A1 I1;
       E2 A2 I2];

%----- Wektor obcie wzowych --------------------------------
 
f = zeros(20,1);
 
% Obcienia wzowe

f(4) = 10e3;
 
% Macierz obcie elementowych eq=[qx qy]; LOKALNY UKAD WSP.

eq = [0 0; 
      0 0; 
      0 1e3; 
      0 0; 
      0 0];
       
%----- Warunki brzegowe -----------------------------------------

bc = [ 1 0; 
       2 0; 
       3 0; 
       7 0; 
       8 0; 
       9 0; 
      14 0; 
      15 0];
      
%----- Globalna macierz sztywnoci -----------------------------
K=zeros(20); 
  [nel,kol]=size(Edof);
for i=1:nel
  [Ke,fe]=beam2e(ex(i,:),ey(i,:),ep(i,:),eq(i,:));
  [K,f]=assem(Edof(i,:),K,Ke,f,fe);
end

%----- Rozwizanie ukadu rwna: przemieszczenia a i reakcje R --
[a,R]=solveq(K,f,bc);


% ----- Przemieszczenia wzw elementu --------------------------
ed=extract(Edof,a);

% ----- Siy przekrojowe ------------------------------------------
% ----- Deformacje elementw
Es=[];  Edi=[];  Eci=[];
n=10; % liczba punktw na dugoci elementu, 
      % w ktrych s obliczane N, Q, M
for i=1:nel
  [es,edi,eci]=beam2s(ex(i,:),ey(i,:),ep(i,:),ed(i,:),eq(i,:),n);
  Es=[Es;es];    % siy przekrojowe, kolejne kolumny to N, Q, M
  Edi=[Edi;edi]; % przemieszczenia kolejnych punktw w lokalnym uk. wsp.
  Eci=[Eci;eci]; % lokalne wsprzdne kolejnych punktw
end;

% -------------------- Wykresy -----------------------------------
% -------------------- Przemieszczenia ---------------------------
 figure(1)
    title('Deformacja ukladu');
    eldraw2(ex,ey,[3 4 1]);     % Niezdeformowana rama
    sfac=scalfact2(ex,ey,ed(end,:),0.1);
    eldisp2(ex,ey,ed,[1 2 1],sfac);  % Zdeformowana rama
    pltscalb2(sfac,[1e-2 0.5 0]);
    axis equal
    xlim([min(Coord(:,1))-2 max(Coord(:,1))+2])
    ylim([min(Coord(:,2))-2 max(Coord(:,2))+2])
    xlabel('[m]')
    ylabel('[m]')

%----------------- Wykres momentw zginajacych -----------------

if sum(Es(:,3))==0 
    disp('*-----!!--Momenty zginajce rwne zero--!!----*');
else 
    figure(2)
    title('Wykres momentow zginajacych');
    % Ustalenie wsplczynnika skalujacego    
    sfac=scalfact2(ex(end,:),ey(end,:),Es(:,3),0.2);
    for i=1:nel
        p = (i-1)*n+1;
        k = n*i;
        eldia2(ex(i,:),ey(i,:),Es(p:k,3),[2 1],sfac);
    end
    pltscalb2(sfac,[1e3 0.5 0]);    
    axis equal
    xlim([min(Coord(:,1))-2 max(Coord(:,1))+2])
    ylim([min(Coord(:,2))-2 max(Coord(:,2))+2])
    xlabel('[m]')
    ylabel('[m]')
end

%------------------ Wykres sil poprzecznych -------------------

if sum(Es(:,2))==0
    disp('*------!!--Siy poprzeczne rwne zero--!!-----*');
else 
    figure(3)
    title('Wykres sil poprzecznych');
    % Ustalenie wsplczynnika skalujacego
    sfac=scalfact2(ex(end,:),ey(end,:),Es(:,2),0.2);
    for i=1:nel
        p = (i-1)*n+1;
        k = n*i;
        eldia2(ex(i,:),ey(i,:),Es(p:k,2),[2 1],sfac);
    end
    pltscalb2(sfac,[1e3 0.5 0]);    
    axis equal
    xlim([min(Coord(:,1))-2 max(Coord(:,1))+2])
    ylim([min(Coord(:,2))-2 max(Coord(:,2))+2])
    xlabel('[m]')
    ylabel('[m]')
end

%------------------- Wykres sil osiowych ---------------------

if sum(Es(:,1))==0
    disp('*-------!!--Siy osiowe rwne zero--!!--------*');
else
    figure(4)
    title('Wykres sil osiowych');
    % Ustalenie wsplczynnika skalujacego
    sfac=scalfact2(ex(end,:),ey(end,:),Es(:,1),0.2);
    for i=1:nel
        p = (i-1)*n+1;
        k = n*i;
        eldia2(ex(i,:),ey(i,:),Es(p:k,1),[2 1],sfac);
    end
    pltscalb2(sfac,[1e3 0.5 0]);
    axis equal
    xlim([min(Coord(:,1))-2 max(Coord(:,1))+2])
    ylim([min(Coord(:,2))-2 max(Coord(:,2))+2])
    xlabel('[m]')
    ylabel('[m]')
end


%----- KONIEC ------------------------------------------
